@@ -1,9 +1,12 @@
 # A function to "identify" points in a "point" object...
 # This function allows the user to identify points graphically.
 assign("identify.point",
-function(point.obj,a,...) {
+function(point.obj,a="",...) {
 
   a <- point.obj[[match(a,names(point.obj))]]
+  if(!is.null(a))
+    identify(point.obj$x,point.obj$y,a,...)
+  else
+    identify(point.obj$x,point.obj$y,...)
 
-  identify(point.obj$x,point.obj$y,a,...)
 })
